<p align="center">
    <img width="250" src="https://cdn.jsdelivr.net/gh/szj2ys/woc/woc/resources/logo.png"/>
</p>

<h3 align="center">
    <p>🛠 Awesome Command toolkit you are waiting for 🛠</p>
</h3>


<p align="center">
    <a href="https://python.org/pypi/woc">
        <img src="https://badge.fury.io/py/woc.svg" alt="Version"/>
    </a>
    <a href="https://python.org/pypi/woc">
        <img src="https://img.shields.io/pypi/l/woc.svg?color=blue" 
alt="License"/>
    </a>
    <a href="https://python.org/pypi/woc">
        <img src="https://static.pepy.tech/badge/woc?color=blue" alt="pypi total downloads"/>
    </a>
    <a href="https://python.org/pypi/woc">
        <img src="https://img.shields.io/github/last-commit/szj2ys/woc?color=blue" alt="GitHub last commit"/>
    </a>
</p>


## Installation🎉 ⚙ 🔑 🎛️ 🙈 🎠 ❌ 🎉  
```shell
pip install woc
```
hahahahaha... now,`woc` is on your environment, having fun with it, enjoy ...

if you need help
```shell
woc -h
```

## Usage 🤔 💭 🤓 💬 😎

Sometimes it is useful to be allowed to invoke more than one subcommand in one go.
For instance:
```shell
woc pypi -pc
```


## REFERENCES
- [`click` Documents](https://click.palletsprojects.com)



